pub struct TestHandler<H>where
    H: GameHandler,{ /* private fields */ }
A wrapped handler for testing This handler includes the general event handling, which is necessary for integration test.

Implementations

source

impl<H: GameHandler> TestHandler<H>

source

pub fn init_state( context: &mut GameContext, game_account: &GameAccount ) -> Result<Self>

source

pub fn handle_event( &mut self, context: &mut GameContext, event: &Event ) -> Result<()>

source

pub fn handle_dispatch_event(&mut self, context: &mut GameContext) -> Result<()>

Find the event which is going to be disptached in the context, then process it. In real cases, the disptached event will be handled by an event loop. We use this function to simulate such cases, since we don’t have an event loop in tests.

source

pub fn handle_until_no_events( &mut self, context: &mut GameContext, event: &Event, clients: Vec<&mut TestClient> ) -> Result<()>

This fn keeps handling events of the following two types, until there is none:

  1. Event dispatched from within the (updated) context: context.dispatch
  2. Event dispatched by clients after they see the updated context
source

pub fn get_state(&self) -> &H

source

pub fn get_mut_state(&mut self) -> &mut H